'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var tslib_1 = require('tslib');
var React = require('react');
var React__default = _interopDefault(React);
var styled = _interopDefault(require('styled-components'));

var createFlexDirectionCalculator = function (defaultProps) { return function (props) {
    return (props.orientation || defaultProps.orientation) === 'vertical'
        ? 'column'
        : (props.direction || defaultProps.direction) === 'right-to-left'
            ? 'row-reverse'
            : 'row';
}; };
var formatSpacingValue = function (value) {
    return !!value ? (isNaN(Number(value)) ? value : value + "px") : undefined;
};
var valueOrDefault = function (defaultValue) { return function (value) {
    return value === undefined || value === null ? defaultValue : value;
}; };

var defaultSequenceProps = {
    orientation: 'vertical',
    direction: 'left-to-right',
};
var calculateFlexDirection = createFlexDirectionCalculator(defaultSequenceProps);
var calculateWidthOrHeightSetting = function (props) {
    return ({
        horizontal: 'height: 100%;',
        vertical: 'width: 100%;',
    }[props.orientation || defaultSequenceProps.orientation]);
};
var StyledStackDiv = styled.div(templateObject_1 || (templateObject_1 = tslib_1.__makeTemplateObject(["\n  display: flex;\n  align-items: center;\n  flex-direction: ", ";\n  vertical-align: top;\n\n  & > * {\n    ", ";\n  }\n"], ["\n  display: flex;\n  align-items: center;\n  flex-direction: ", ";\n  vertical-align: top;\n\n  & > * {\n    ", ";\n  }\n"])), calculateFlexDirection, calculateWidthOrHeightSetting);
var StackChild = function (props) { return React.createElement(React.Fragment, null, props.children); };
var Stack = function (props) { return (React.createElement(StyledStackDiv, tslib_1.__assign({}, props), props.children)); };
var templateObject_1;

var calculateFlexDirection$1 = createFlexDirectionCalculator({
    orientation: 'horizontal',
    direction: 'left-to-right',
});
var calculateFlexWrap = function (props) {
    if (props.orientation === 'vertical') {
        return {
            'left-to-right': 'wrap',
            'right-to-left': 'wrap-reverse',
        }[props.direction || 'left-to-right'];
    }
    return 'wrap';
};
var StyledWrapDiv = styled.div(templateObject_1$1 || (templateObject_1$1 = tslib_1.__makeTemplateObject(["\n  display: flex;\n  flex-direction: ", ";\n  flex-wrap: ", ";\n"], ["\n  display: flex;\n  flex-direction: ", ";\n  flex-wrap: ", ";\n"])), calculateFlexDirection$1, calculateFlexWrap);
var WrapChild = function (props) { return React.createElement(React.Fragment, null, props.children); };
var Wrap = function (props) { return (React.createElement(StyledWrapDiv, tslib_1.__assign({}, props), props.children)); };
var templateObject_1$1;

var defaultDockChildProps = { dock: 'left' };
var StyledDockChildDiv = styled.div(templateObject_1$2 || (templateObject_1$2 = tslib_1.__makeTemplateObject(["\n  display: flex;\n  flex-direction: ", ";\n  width: 100%;\n  height: 100%;\n  box-sizing: border-box;\n\n  ", "\n"], ["\n  display: flex;\n  flex-direction: ",
    ";\n  width: 100%;\n  height: 100%;\n  box-sizing: border-box;\n\n  ",
    "\n"])), function (props) {
    return ({
        top: 'column',
        right: 'row-reverse',
        bottom: 'column-reverse',
        left: 'row',
    }[props.dockChildren[0].props.dock || defaultDockChildProps.dock]);
}, function (props) {
    return (!!props.dockProps.lastChildFill && props.dockChildren.length === 1) ||
        !!props.dockChildren[0].props.fill
        ? "\n      > * {\n        flex: 1;\n      }\n    "
        : undefined;
});
var wrapChildrenInNestedContainers = function (props) { return (React.createElement(StyledDockChildDiv, { dockProps: props, dockChildren: props.children },
    props.children[0],
    props.children.length > 1
        ? wrapChildrenInNestedContainers(tslib_1.__assign({}, props, { children: props.children.slice(1) }))
        : undefined)); };
var DockChild = function (props) { return React.createElement(React.Fragment, null, props.children); };
var Dock = function (_a) {
    var lastChildFill = _a.lastChildFill, props = tslib_1.__rest(_a, ["lastChildFill"]);
    return (React.createElement("div", tslib_1.__assign({}, props), wrapChildrenInNestedContainers(tslib_1.__assign({ lastChildFill: lastChildFill }, props))));
};
var templateObject_1$2;

var getDefinitionSize = function (dimension, props) {
    return dimension === 'row'
        ? (props.rowDefinitions || []).map(function (d) { return d.height; })
        : dimension === 'column'
            ? (props.columnDefinitions || []).map(function (d) { return d.width; })
            : [];
};
var mapDefinitionSize = function (size) {
    return valueOrDefault('1fr')(formatSpacingValue(size));
};
var generateGridTemplateUnit = function (dimension) { return function (props) {
    return getDefinitionSize(dimension, props)
        .map(mapDefinitionSize)
        .join(' ');
}; };
var StyledGridDiv = styled.div(templateObject_1$3 || (templateObject_1$3 = tslib_1.__makeTemplateObject(["\n  display: grid;\n  grid-template-rows: ", ";\n  grid-template-columns: ", ";\n\n  ", ";\n"], ["\n  display: grid;\n  grid-template-rows: ", ";\n  grid-template-columns: ", ";\n\n  ",
    ";\n"])), generateGridTemplateUnit('row'), generateGridTemplateUnit('column'), function (props) {
    return props.children
        .map(function (child, index) { return "\n        & > *:nth-child(" + (index + 1) + ") {\n          grid-row-start: " + child.props.gridRow + ";\n          grid-row-end: " + (child.props.gridRow +
        (child.props.gridRowSpan || 0)) + ";\n          grid-column-start: " + child.props.gridColumn + ";\n          grid-column-end: " + (child.props.gridColumn +
        (child.props.gridColumnSpan || 0)) + ";\n        }"; })
        .join('');
});
var GridChild = function (props) { return React.createElement(React.Fragment, null, props.children); };
var Grid = function (props) { return (React.createElement(StyledGridDiv, tslib_1.__assign({}, props), props.children)); };
var templateObject_1$3;

var StyledCanvasDiv = styled.div(templateObject_1$4 || (templateObject_1$4 = tslib_1.__makeTemplateObject(["\n  position: relative;\n\n  ", ";\n"], ["\n  position: relative;\n\n  ",
    ";\n"])), function (props) {
    var valueOrInitial = valueOrDefault('initial');
    var formatPositionValue = function (value) {
        return valueOrInitial(formatSpacingValue(value));
    };
    return props.children
        .map(function (child, index) { return "\n        & > *:nth-child(" + (index + 1) + ") {\n          position: absolute;\n          top: " + formatPositionValue(child.props.canvasTop) + ";\n          right: " + formatPositionValue(child.props.canvasRight) + ";\n          bottom: " + formatPositionValue(child.props.canvasBottom) + ";\n          left: " + formatPositionValue(child.props.canvasLeft) + ";\n          z-index: " + valueOrInitial(child.props.canvasZIndex) + ";\n        }"; })
        .join('');
});
var CanvasChild = function (props) { return React.createElement(React.Fragment, null, props.children); };
var Canvas = function (props) { return (React.createElement(StyledCanvasDiv, tslib_1.__assign({}, props), props.children)); };
var templateObject_1$4;

var generateGridTemplateUnit$1 = function (field) { return function (props) {
    return Array(props[field])
        .fill(0)
        .map(function () { return '1fr'; })
        .join(' ');
}; };
var StyledUniformGridDiv = styled.div(templateObject_1$5 || (templateObject_1$5 = tslib_1.__makeTemplateObject(["\n  display: grid;\n  grid-template-rows: ", ";\n  grid-template-columns: ", ";\n"], ["\n  display: grid;\n  grid-template-rows: ", ";\n  grid-template-columns: ", ";\n"])), generateGridTemplateUnit$1('rows'), generateGridTemplateUnit$1('columns'));
var UniformGridChild = function (props) { return (React.createElement(React.Fragment, null, props.children)); };
var UniformGrid = function (props) { return (React.createElement(StyledUniformGridDiv, tslib_1.__assign({}, props), props.children)); };
var templateObject_1$5;

exports.StackChild = StackChild;
exports.Stack = Stack;
exports.WrapChild = WrapChild;
exports.Wrap = Wrap;
exports.DockChild = DockChild;
exports.Dock = Dock;
exports.GridChild = GridChild;
exports.Grid = Grid;
exports.CanvasChild = CanvasChild;
exports.Canvas = Canvas;
exports.UniformGridChild = UniformGridChild;
exports.UniformGrid = UniformGrid;
//# sourceMappingURL=react-layout-wrappers.cjs.production.js.map
