import { __makeTemplateObject, __assign, __rest } from 'tslib';
import { createElement, Fragment } from 'react';
import styled from 'styled-components';

var createFlexDirectionCalculator = function (defaultProps) {
  return function (props) {
    return (props.orientation || defaultProps.orientation) === 'vertical' ? 'column' : (props.direction || defaultProps.direction) === 'right-to-left' ? 'row-reverse' : 'row';
  };
};
var formatSpacingValue = function (value) {
  return !!value ? isNaN(Number(value)) ? value : value + "px" : undefined;
};
var valueOrDefault = function (defaultValue) {
  return function (value) {
    return value === undefined || value === null ? defaultValue : value;
  };
};

var defaultSequenceProps = {
  orientation: 'vertical',
  direction: 'left-to-right'
};
var calculateFlexDirection =
/*#__PURE__*/
createFlexDirectionCalculator(defaultSequenceProps);

var calculateWidthOrHeightSetting = function (props) {
  return {
    horizontal: 'height: 100%;',
    vertical: 'width: 100%;'
  }[props.orientation || defaultSequenceProps.orientation];
};

var StyledStackDiv =
/*#__PURE__*/
styled.div(templateObject_1 || (templateObject_1 =
/*#__PURE__*/
__makeTemplateObject(["\n  display: flex;\n  align-items: center;\n  flex-direction: ", ";\n  vertical-align: top;\n\n  & > * {\n    ", ";\n  }\n"], ["\n  display: flex;\n  align-items: center;\n  flex-direction: ", ";\n  vertical-align: top;\n\n  & > * {\n    ", ";\n  }\n"])), calculateFlexDirection, calculateWidthOrHeightSetting);
var StackChild = function (props) {
  return createElement(Fragment, null, props.children);
};
var Stack = function (props) {
  return createElement(StyledStackDiv, __assign({}, props), props.children);
};
var templateObject_1;

var calculateFlexDirection$1 =
/*#__PURE__*/
createFlexDirectionCalculator({
  orientation: 'horizontal',
  direction: 'left-to-right'
});

var calculateFlexWrap = function (props) {
  if (props.orientation === 'vertical') {
    return {
      'left-to-right': 'wrap',
      'right-to-left': 'wrap-reverse'
    }[props.direction || 'left-to-right'];
  }

  return 'wrap';
};

var StyledWrapDiv =
/*#__PURE__*/
styled.div(templateObject_1$1 || (templateObject_1$1 =
/*#__PURE__*/
__makeTemplateObject(["\n  display: flex;\n  flex-direction: ", ";\n  flex-wrap: ", ";\n"], ["\n  display: flex;\n  flex-direction: ", ";\n  flex-wrap: ", ";\n"])), calculateFlexDirection$1, calculateFlexWrap);
var WrapChild = function (props) {
  return createElement(Fragment, null, props.children);
};
var Wrap = function (props) {
  return createElement(StyledWrapDiv, __assign({}, props), props.children);
};
var templateObject_1$1;

var defaultDockChildProps = {
  dock: 'left'
};
var StyledDockChildDiv =
/*#__PURE__*/
styled.div(templateObject_1$2 || (templateObject_1$2 =
/*#__PURE__*/
__makeTemplateObject(["\n  display: flex;\n  flex-direction: ", ";\n  width: 100%;\n  height: 100%;\n  box-sizing: border-box;\n\n  ", "\n"], ["\n  display: flex;\n  flex-direction: ", ";\n  width: 100%;\n  height: 100%;\n  box-sizing: border-box;\n\n  ", "\n"])), function (props) {
  return {
    top: 'column',
    right: 'row-reverse',
    bottom: 'column-reverse',
    left: 'row'
  }[props.dockChildren[0].props.dock || defaultDockChildProps.dock];
}, function (props) {
  return !!props.dockProps.lastChildFill && props.dockChildren.length === 1 || !!props.dockChildren[0].props.fill ? "\n      > * {\n        flex: 1;\n      }\n    " : undefined;
});

var wrapChildrenInNestedContainers = function (props) {
  return createElement(StyledDockChildDiv, {
    dockProps: props,
    dockChildren: props.children
  }, props.children[0], props.children.length > 1 ? wrapChildrenInNestedContainers(__assign({}, props, {
    children: props.children.slice(1)
  })) : undefined);
};

var DockChild = function (props) {
  return createElement(Fragment, null, props.children);
};
var Dock = function (_a) {
  var lastChildFill = _a.lastChildFill,
      props = __rest(_a, ["lastChildFill"]);

  return createElement("div", __assign({}, props), wrapChildrenInNestedContainers(__assign({
    lastChildFill: lastChildFill
  }, props)));
};
var templateObject_1$2;

var getDefinitionSize = function (dimension, props) {
  return dimension === 'row' ? (props.rowDefinitions || []).map(function (d) {
    return d.height;
  }) : dimension === 'column' ? (props.columnDefinitions || []).map(function (d) {
    return d.width;
  }) : [];
};

var mapDefinitionSize = function (size) {
  return valueOrDefault('1fr')(formatSpacingValue(size));
};

var generateGridTemplateUnit = function (dimension) {
  return function (props) {
    return getDefinitionSize(dimension, props).map(mapDefinitionSize).join(' ');
  };
};

var StyledGridDiv =
/*#__PURE__*/
styled.div(templateObject_1$3 || (templateObject_1$3 =
/*#__PURE__*/
__makeTemplateObject(["\n  display: grid;\n  grid-template-rows: ", ";\n  grid-template-columns: ", ";\n\n  ", ";\n"], ["\n  display: grid;\n  grid-template-rows: ", ";\n  grid-template-columns: ", ";\n\n  ", ";\n"])),
/*#__PURE__*/
generateGridTemplateUnit('row'),
/*#__PURE__*/
generateGridTemplateUnit('column'), function (props) {
  return props.children.map(function (child, index) {
    return "\n        & > *:nth-child(" + (index + 1) + ") {\n          grid-row-start: " + child.props.gridRow + ";\n          grid-row-end: " + (child.props.gridRow + (child.props.gridRowSpan || 0)) + ";\n          grid-column-start: " + child.props.gridColumn + ";\n          grid-column-end: " + (child.props.gridColumn + (child.props.gridColumnSpan || 0)) + ";\n        }";
  }).join('');
});
var GridChild = function (props) {
  return createElement(Fragment, null, props.children);
};
var Grid = function (props) {
  return createElement(StyledGridDiv, __assign({}, props), props.children);
};
var templateObject_1$3;

var StyledCanvasDiv =
/*#__PURE__*/
styled.div(templateObject_1$4 || (templateObject_1$4 =
/*#__PURE__*/
__makeTemplateObject(["\n  position: relative;\n\n  ", ";\n"], ["\n  position: relative;\n\n  ", ";\n"])), function (props) {
  var valueOrInitial = valueOrDefault('initial');

  var formatPositionValue = function (value) {
    return valueOrInitial(formatSpacingValue(value));
  };

  return props.children.map(function (child, index) {
    return "\n        & > *:nth-child(" + (index + 1) + ") {\n          position: absolute;\n          top: " + formatPositionValue(child.props.canvasTop) + ";\n          right: " + formatPositionValue(child.props.canvasRight) + ";\n          bottom: " + formatPositionValue(child.props.canvasBottom) + ";\n          left: " + formatPositionValue(child.props.canvasLeft) + ";\n          z-index: " + valueOrInitial(child.props.canvasZIndex) + ";\n        }";
  }).join('');
});
var CanvasChild = function (props) {
  return createElement(Fragment, null, props.children);
};
var Canvas = function (props) {
  return createElement(StyledCanvasDiv, __assign({}, props), props.children);
};
var templateObject_1$4;

var generateGridTemplateUnit$1 = function (field) {
  return function (props) {
    return Array(props[field]).fill(0).map(function () {
      return '1fr';
    }).join(' ');
  };
};

var StyledUniformGridDiv =
/*#__PURE__*/
styled.div(templateObject_1$5 || (templateObject_1$5 =
/*#__PURE__*/
__makeTemplateObject(["\n  display: grid;\n  grid-template-rows: ", ";\n  grid-template-columns: ", ";\n"], ["\n  display: grid;\n  grid-template-rows: ", ";\n  grid-template-columns: ", ";\n"])),
/*#__PURE__*/
generateGridTemplateUnit$1('rows'),
/*#__PURE__*/
generateGridTemplateUnit$1('columns'));
var UniformGridChild = function (props) {
  return createElement(Fragment, null, props.children);
};
var UniformGrid = function (props) {
  return createElement(StyledUniformGridDiv, __assign({}, props), props.children);
};
var templateObject_1$5;

export { StackChild, Stack, WrapChild, Wrap, DockChild, Dock, GridChild, Grid, CanvasChild, Canvas, UniformGridChild, UniformGrid };
//# sourceMappingURL=react-layout.esm.js.map
